@@ -8,6 +8,7 @@
 #   decimal
 #   add meta-data in tuner's returns
 #   add "tradingview backtest"
+#   exponential regression and stable growth in tester
 
 from copy import copy
 from datetime import datetime
@@ -62,9 +63,7 @@ class Trader(object):
     _credit_leverages: List[Union[float, int]]
     deposit_history: List[Union[float, int]]
     year_profit: float
-    average_growth: ndarray
     _info: str
-    _backtest_out_no_drop: DataFrame
     backtest_out: DataFrame
     _open_lot_prices: List[float]
     client: TradingClient
@@ -81,6 +80,14 @@ class Trader(object):
     def _converted(self) -> utils.CONVERTED_TYPE_LIST:
         return utils.convert(self.returns)
 
+    @property
+    def mean_deviation(self) -> float:
+        return utils.mean_deviation(Series(self.deposit_history), self.average_growth) * 100
+
+    @property
+    def average_growth(self) -> ndarray:
+        return utils.get_exponential_growth(self.deposit_history)
+
     @utils.assert_logger
     def __init__(self,
                  ticker: str = 'BTC/USDT',
@@ -428,9 +435,8 @@ class Trader(object):
             prev_sig = sig
             ignore_breakout = False
 
-        self.average_growth = utils.get_exponential_growth(self.deposit_history)
         if not pass_math:
-            self.year_profit = utils.profit_factor(self.deposit_history) ** (self._profit_calculate_coef - 1)
+            self.year_profit = utils.profit_factor(self.average_growth) ** (self._profit_calculate_coef - 1)
             #  Compound interest. View https://www.investopedia.com/terms/c/compoundinterest.asp
             self.year_profit -= 1  # The initial deposit does not count as profit
             self.year_profit *= 100  # Percentage
@@ -439,13 +445,13 @@ class Trader(object):
             else:
                 self.winrate = 0
                 utils.logger.critical('0 trades in %s', self)
-        self._info = utils.INFO_TEXT.format(self.losses, self.trades, self.profits, self.year_profit, self.winrate)
+        self._info = utils.INFO_TEXT.format(self.losses, self.trades, self.profits, self.year_profit, self.winrate, self.mean_deviation)
         utils.logger.info('trader info: %s', self._info)
         if print_out:
             print(self._info)
         self.returns_strategy_diff = list(Series(self.deposit_history).diff().values)
         self.returns_strategy_diff[0] = 0
-        self._backtest_out_no_drop = DataFrame(
+        self.backtest_out = DataFrame(
             (self.deposit_history, self._stop_losses, self._take_profits, self.returns,
              self._open_lot_prices, data_column, self.average_growth, self.returns_strategy_diff),
             index=[
@@ -454,7 +460,6 @@ class Trader(object):
                 f"average growth deposit data",
                 "returns"
             ]).T
-        self.backtest_out = self._backtest_out_no_drop.dropna()
         if plot:
             self.fig.plot_candlestick()
             self.fig.plot_trade_triangles()
@@ -544,19 +549,17 @@ class Trader(object):
         for multiplier in multipliers.values:
             deposit_elem *= multiplier
             self.deposit_history.append(deposit_elem)
-        self.average_growth = utils.get_exponential_growth(self.deposit_history)
         self.returns_strategy_diff = list(Series(self.deposit_history).diff().values)
         self.returns_strategy_diff[0] = 0
-        self._backtest_out_no_drop = DataFrame(
+        self.backtest_out = DataFrame(
             (self.deposit_history, self.average_growth, self.returns_strategy_diff),
             index=[
                 f'deposit',
                 f"average growth deposit data",
                 "returns"
             ]).T
-        self.backtest_out = self._backtest_out_no_drop.dropna()
 
-        self._info = utils.INFO_TEXT.format(self.losses, self.trades, self.profits, self.year_profit, self.winrate)
+        self._info = utils.INFO_TEXT.format(self.losses, self.trades, self.profits, self.year_profit, self.winrate, self.mean_deviation)
         utils.logger.info('trader multi info: %s', self._info)
         if print_out:
             print(self._info)
