@@ -17,6 +17,10 @@ from numpy import nan_to_num
 from numpy import ndarray
 from pandas import DataFrame
 from pandas import Series
+from numpy import arange
+from numpy import polyfit
+from numpy import exp
+from numpy import log
 from ta.volatility import AverageTrueRange
 
 PREDICT_TYPE: type = int
@@ -160,9 +164,10 @@ INFO_TEXT: str = """losses: {}
 trades: {}
 profits: {}
 mean year percentage profit: {}%
-winrate: {}%"""  # .format(Trader.losses, Trader.trades, Trader.profits, Trader.year_profit, Trader.winrate)
+winrate: {}%
+mean deviation: {}%"""  # .format(Trader.losses, Trader.trades, Trader.profits, Trader.year_profit, Trader.winrate, Trader.mean_deviation)
 
-__version__: str = "6.5.5"
+__version__: str = "6.6.0"
 __author__: str = 'Vlad Kochetov'
 __credits__: List[str] = [
     "Hemerson Tacon -- Stack overflow",
@@ -321,13 +326,10 @@ def convert_signal_str(predict: PREDICT_TYPE) -> str:
 
 
 def get_exponential_growth(dataset: Sequence[float]) -> ndarray:
-    return_list: List[float] = []
-    coef = profit_factor(dataset)
-    curr = dataset[0]
-    for i in range(len(dataset)):
-        return_list.append(curr)
-        curr *= coef
-    return array(return_list)
+    x = arange(1, len(dataset)+1, 1)
+    b, a = polyfit(x, log(array(dataset)), 1)
+    regression = exp(a + b*x)
+    return array(regression)
 
 
 def get_coef_sec(timeframe: str = '1d') -> Tuple[float, int]:
@@ -416,12 +418,8 @@ def wait_success(func):
     return checker
 
 
-def root(x: float, pwr: float = 2.0) -> float:
-    return x ** (1 / pwr)
-
-
-def profit_factor(deposit_list: Sequence) -> float:
-    return root(deposit_list[-1] / deposit_list[0], len(deposit_list) - 1)
+def profit_factor(deposit_list: Sequence[float]) -> float:
+    return deposit_list[1] / deposit_list[0]
 
 
 def assert_logger(func):
@@ -490,3 +488,7 @@ def get_multipliers(df: pd.Series) -> pd.Series:
     ret: pd.Series = df / df.shift(1)
     ret[0] = 1
     return ret
+
+def mean_deviation(frame: Series, avg_grwth: ndarray) -> float:
+    relative_diff = abs(frame.values - avg_grwth) / avg_grwth
+    return relative_diff.mean()
